Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(16)

Unified Diff: ui/events/platform/x11/x11_event_source.h

Issue 2287583003: Linux: Remove --wm-user-time-ms command line argument (Closed)
Patch Set: Deprecate histogram Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/base/x/selection_owner.cc ('k') | ui/events/platform/x11/x11_event_source.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/events/platform/x11/x11_event_source.h
diff --git a/ui/events/platform/x11/x11_event_source.h b/ui/events/platform/x11/x11_event_source.h
index 81c9b171dae21bf311f1e53fe069aa27417caa1a..bd925027856034e64c30dee5786a9a07486f7a15 100644
--- a/ui/events/platform/x11/x11_event_source.h
+++ b/ui/events/platform/x11/x11_event_source.h
@@ -70,19 +70,10 @@ class EVENTS_EXPORT X11EventSource {
void BlockUntilWindowUnmapped(XID window);
XDisplay* display() { return display_; }
- Time last_seen_server_time() const { return last_seen_server_time_; }
-
- // Explicitly asks the X11 server for the current timestamp, and updates
- // |last_seen_server_time_| with this value.
- Time UpdateLastSeenServerTime();
-
- // Sets |last_seen_server_time_| to |time| if this would cause the time to
- // move forward.
- void SetLastSeenServerTime(Time time);
// Returns the timestamp of the event currently being dispatched. Falls back
// on UpdateLastSeenServerTime() if there's no event being dispatched, or if
// the current event does not have a timestamp.
Time GetTimestamp();
void StopCurrentEventStream();
@@ -101,6 +92,10 @@ class EVENTS_EXPORT X11EventSource {
// Dispatch all encountered events prior to the one we're blocking on.
void BlockOnWindowStructureEvent(XID window, int type);
+ // Explicitly asks the X11 server for the current timestamp, and updates
+ // |last_seen_server_time_| with this value.
+ Time GetCurrentServerTime();
+
private:
static X11EventSource* instance_;
@@ -109,9 +104,6 @@ class EVENTS_EXPORT X11EventSource {
// The connection to the X11 server used to receive the events.
XDisplay* display_;
- // The last timestamp seen in an XEvent.
- Time last_seen_server_time_;
-
// The timestamp of the event being dispatched.
Time event_timestamp_;
« no previous file with comments | « ui/base/x/selection_owner.cc ('k') | ui/events/platform/x11/x11_event_source.cc » ('j') | no next file with comments »
@@ -70,19 +70,10 @@ class EVENTS_EXPORT X11EventSource {
// Returns the timestamp of the event currently being dispatched. Falls back
- // on UpdateLastSeenServerTime() if there's no event being dispatched, or if
- // the current event does not have a timestamp.
+ // on GetCurrentServerTime() if there's no event being dispatched, or if the
+ // current event does not have a timestamp.
Time GetTimestamp();
void StopCurrentEventStream();

Powered by Google App Engine
This is Rietveld 408576698